@@ -1,15 +1,14 @@
 from paf.common import Size, Rect
-from paf.manager import WebDriverManager
-from paf.request import WebDriverRequest
 from paf.javascript import get_viewport
+from paf.request import WebDriverRequest
+from test import create_webdriver
 
 
 def test_viewport():
     request = WebDriverRequest()
     request.browser = "chrome"
     request.window_size = Size(1024, 768)
-    manager = WebDriverManager()
-    webdriver = manager.get_webdriver(request)
+    webdriver = create_webdriver(request)
     viewport = get_viewport(webdriver)
     assert isinstance(viewport, Rect)
     assert viewport.top == 0
